searchNodes=[{"doc":"The main feature provided by this module is the ability to set the HTML and/or text body of an email by rendering templates. It has been designed to integrate with Phoenix view, template and layout system.","ref":"Phoenix.Swoosh.html","title":"Phoenix.Swoosh","type":"module"},{"doc":"Retrieves the current layout of an email.","ref":"Phoenix.Swoosh.html#layout/1","title":"Phoenix.Swoosh.layout/1","type":"function"},{"doc":"Stores the layout for rendering. The layout must be a tuple, specifying the layout view and the layout name, or false. In case a previous layout is set, put_layout also accepts the layout name to be given as a string or as an atom. If a string, it must contain the format. Passing an atom means the layout format will be found at rendering time, similar to the template in render_body/3 . It can also be set to false . In this case, no layout would be used. Examples iex&gt; layout ( email ) false iex&gt; email = put_layout email , { LayoutView , &quot;email.html&quot; } iex&gt; layout ( email ) { LayoutView , &quot;email.html&quot; } iex&gt; email = put_layout email , &quot;email.html&quot; iex&gt; layout ( email ) { LayoutView , &quot;email.html&quot; } iex&gt; email = put_layout email , :email iex&gt; layout ( email ) { AppView , :email }","ref":"Phoenix.Swoosh.html#put_layout/2","title":"Phoenix.Swoosh.put_layout/2","type":"function"},{"doc":"Stores the layout for rendering if one was not stored yet.","ref":"Phoenix.Swoosh.html#put_new_layout/2","title":"Phoenix.Swoosh.put_new_layout/2","type":"function"},{"doc":"Stores the view for rendering if one was not stored yet.","ref":"Phoenix.Swoosh.html#put_new_view/2","title":"Phoenix.Swoosh.put_new_view/2","type":"function"},{"doc":"Stores the view for rendering.","ref":"Phoenix.Swoosh.html#put_view/2","title":"Phoenix.Swoosh.put_view/2","type":"function"},{"doc":"Renders the given template and assigns based on the email . Once the template is rendered the resulting string is stored on the email fields html_body and text_body depending on the format of the template. .html , .htm , and .xml are stored in html_body ; all other extensions, (e.g. .txt and .text ), in text_body . Arguments email - the Swoosh.Email struct. template - may be an atom or a string. If an atom, like :welcome , it will render both the HTML and text template and stores them respectively on the email. If the template is a string it must contain the extension too, like welcome.html . assigns - a dictionary with the assigns to be used in the view. Those assigns are merged and have higher order precedence than the email assigns. ( email.assigns ) Examples defmodule Sample.UserEmail do use Phoenix.Swoosh , view : Sample.EmailView def welcome ( user ) do % Email { } |&gt; from ( &quot;tony@stark.com&quot; ) |&gt; to ( user . email ) |&gt; subject ( &quot;Hello, Avengers!&quot; ) |&gt; render_body ( &quot;welcome.html&quot; , %{ username : user . email } ) end end The example above renders a template welcome.html from Sample.EmailView and stores the resulting string onto the html_body field of the email. ( email.html_body ) In many cases you may want to set both the html and text body of an email. To do so you can pass the template name as an atom (without the extension): def welcome ( user ) do % Email { } |&gt; from ( &quot;tony@stark.com&quot; ) |&gt; to ( user . email ) |&gt; subject ( &quot;Hello, Avengers!&quot; ) |&gt; render_body ( :welcome , %{ username : user . email } ) end Layouts Templates are often rendered inside layouts. If you wish to do so you will have to specify which layout you want to use when using the Phoenix.Swoosh module. defmodule Sample.UserEmail do use Phoenix.Swoosh , view : Sample.EmailView , layout : { Sample.LayoutView , :email } def welcome ( user ) do % Email { } |&gt; from ( &quot;tony@stark.com&quot; ) |&gt; to ( user . email ) |&gt; subject ( &quot;Hello, Avengers!&quot; ) |&gt; render_body ( &quot;welcome.html&quot; , %{ username : user . email } ) end end The example above will render the welcome.html template inside an email.html template specified in Sample.LayoutView . put_layout/2 can be used to change the layout, similar to how put_view/2 can be used to change the view.","ref":"Phoenix.Swoosh.html#render_body/3","title":"Phoenix.Swoosh.render_body/3","type":"function"},{"doc":"Phoenix.Swoosh Use Swoosh to easily send emails in your Phoenix project. This module provides the ability to set the HTML and/or text body of an email by rendering templates.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"Add :phoenix_swoosh to your list of dependencies in mix.exs : def deps do [ { :phoenix_swoosh , &quot;~&gt; 0.3&quot; } ] end","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"Setting up the templates: # web/templates/layout/email.html.eex &lt; html &gt; &lt; head &gt; &lt; title &gt; &lt; % = @email . subject % &gt; &lt; / title &gt; &lt; / head &gt; &lt; body &gt; &lt; % = @inner_content % &gt; &lt; / body &gt; &lt; / html &gt; # web/templates/email/welcome.html.eex &lt; div &gt; &lt; h1 &gt; Welcome to Sample , &lt; % = @username % &gt; ! &lt; / h1 &gt; &lt; / div &gt; Passing values to templates: # web/emails/user_email.ex defmodule Sample.UserEmail do use Phoenix.Swoosh , view : Sample.EmailView , layout : { Sample.LayoutView , :email } def welcome ( user ) do new ( ) |&gt; from ( &quot;tony@stark.com&quot; ) |&gt; to ( user . email ) |&gt; subject ( &quot;Hello, Avengers!&quot; ) |&gt; render_body ( &quot;welcome.html&quot; , %{ username : user . email } ) end end","ref":"readme.html#usage","title":"Overview - Usage","type":"extras"},{"doc":"Copyright (c) 2016 Swoosh contributors Released under the MIT License, which can be found in LICENSE.md .","ref":"readme.html#copyright-and-license","title":"Overview - Copyright and License","type":"extras"},{"doc":"Changelog All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Changed Bump phoenix_html to unblock upgrades for projects use phoenix_swoosh 0.3.x","ref":"changelog.html#v0-3-4-2021-08-21","title":"Changelog - v0.3.4 - 2021-08-21","type":"extras"},{"doc":"Changed Misc doc changes @kianmeng (#186)","ref":"changelog.html#v0-3-3-2021-04-04","title":"Changelog - v0.3.3 - 2021-04-04","type":"extras"},{"doc":"Added Set correct body field depending on template format @wmnnd (#154)","ref":"changelog.html#v0-3-2-2020-10-13","title":"Changelog - v0.3.2 - 2020-10-13","type":"extras"},{"doc":"Changes Fix warnings on Elixir v1.11 about missing apps @josevalim (#152)","ref":"changelog.html#v0-3-1-2020-10-13","title":"Changelog - v0.3.1 - 2020-10-13","type":"extras"},{"doc":"Changed Bump Swoosh to 1.0","ref":"changelog.html#v0-3-0-2020-07-14","title":"Changelog - v0.3.0 - 2020-07-14","type":"extras"},{"doc":"Changed Removed usage of deprecated Dict .","ref":"changelog.html#v0-2-0-2017-02-13","title":"Changelog - v0.2.0 - 2017-02-13","type":"extras"},{"doc":"Added Add swoosh to the list of applications in mix.exs . Changed Bump phoenix to 1.2. Bump phoenix_html to 2.6. Bump swoosh to 0.4.","ref":"changelog.html#v0-1-3-2016-06-26","title":"Changelog - v0.1.3 - 2016-06-26","type":"extras"},{"doc":"Added Add support for Phoenix 1.2 release candidate.","ref":"changelog.html#v0-1-2-2016-06-12","title":"Changelog - v0.1.2 - 2016-06-12","type":"extras"},{"doc":"Fixed Add default assigns value to render_body/3 inside the use macro","ref":"changelog.html#v0-1-1-2016-04-17","title":"Changelog - v0.1.1 - 2016-04-17","type":"extras"},{"doc":"Initial version","ref":"changelog.html#v0-1-0-2016-03-22","title":"Changelog - v0.1.0 - 2016-03-22","type":"extras"},{"doc":"Contributing","ref":"contributing.html","title":"Contributing","type":"extras"},{"doc":"Clone the repo and fetch its dependencies: $ git clone https://github.com/swoosh/phoenix_swoosh.git $ cd phoenix_swoosh $ mix deps.get $ mix test","ref":"contributing.html#running-tests","title":"Contributing - Running tests","type":"extras"},{"doc":"Documentation is written into the library, you will find it in the source code, accessible from iex and of course, it all gets published to hexdocs . $ mix docs","ref":"contributing.html#building-docs","title":"Contributing - Building docs","type":"extras"},{"doc":"The MIT License (MIT) Copyright (c) 2016 Swoosh contributors Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"}]